.. _tutorials:

Tutorials
=========
Here is a list of available tutorials:


`Digit Classification <https://nbviewer.jupyter.org/github/ysig/grakel/blob/0.1a7/tutorials/digit_classification/digit_classification.ipynb>`_
------------------------------------------------------------------------------------------------------------------------------------------------------
This tutorial explores how an object recognition task can be formulated as a graph classification problem and solved using graph kernels.


`Text Categorization <https://nbviewer.jupyter.org/github/ysig/grakel/blob/0.1a7/tutorials/text_categorization/text_categorization.ipynb>`_
----------------------------------------------------------------------------------------------------------------------------------------------------
In this tutorial, graph kernels are applied to the task of text categorization. Documents are represented as word co-occurence networks and then graph kernels are employed to classify the emerging graphs.